@@ -1,5 +1,5 @@
 /* ************************************************************************
- * Copyright (C) 2018-2023 Advanced Micro Devices, Inc. All rights Reserved.
+ * Copyright (C) 2018-2024 Advanced Micro Devices, Inc. All rights Reserved.
  *
  * Permission is hereby granted, free of charge, to any person obtaining a copy
  * of this software and associated documentation files (the "Software"), to deal
@@ -517,6 +517,32 @@ typedef enum rocsparse_spmat_attribute_
     rocsparse_spmat_storage_mode = 3 /**< Matrix storage attribute. */
 } rocsparse_spmat_attribute;
 
+/*! \ingroup types_module
+   *  \brief List of sparse to sparse algorithms.
+   *
+   *  \details
+   *  This is a list of supported \ref rocsparse_sparse_to_sparse_alg types that are used to perform
+   *  sparse to sparse conversion.
+   */
+typedef enum rocsparse_sparse_to_sparse_alg_
+{
+    rocsparse_sparse_to_sparse_alg_default
+    = 0, /**< Default sparse to sparse algorithm for the given format. */
+} rocsparse_sparse_to_sparse_alg;
+
+/*! \ingroup types_module
+   *  \brief List of sparse_to_sparse stages.
+   *
+   *  \details
+   *  This is a list of possible stages during sparse_to_sparse conversion. Typical order is
+   *  rocsparse_sparse_to_sparse_buffer_size, rocsparse_sparse_to_sparse_preprocess, rocsparse_sparse_to_sparse_compute.
+   */
+typedef enum rocsparse_sparse_to_sparse_stage_
+{
+    rocsparse_sparse_to_sparse_stage_analysis = 0, /**< Data analysis. */
+    rocsparse_sparse_to_sparse_stage_compute  = 1 /**< Performs the actual conversion. */
+} rocsparse_sparse_to_sparse_stage;
+
 /*! \ingroup types_module
  *  \brief List of Iterative ILU0 algorithms.
  *
@@ -615,7 +641,8 @@ typedef enum rocsparse_spmv_alg_
     rocsparse_spmv_alg_csr_stream   = 3, /**< CSR SpMV algorithm 2 (stream) for CSR matrices. */
     rocsparse_spmv_alg_ell          = 4, /**< ELL SpMV algorithm for ELL matrices. */
     rocsparse_spmv_alg_coo_atomic   = 5, /**< COO SpMV algorithm 2 (atomic) for COO matrices. */
-    rocsparse_spmv_alg_bsr          = 6 /**< BSR SpMV algorithm 1 for BSR matrices. */
+    rocsparse_spmv_alg_bsr          = 6, /**< BSR SpMV algorithm 1 for BSR matrices. */
+    rocsparse_spmv_alg_csr_lrb      = 7 /**< CSR SpMV algorithm 3 (LRB) for CSR matrices. */
 } rocsparse_spmv_alg;
 
 /*! \ingroup types_module
@@ -710,10 +737,13 @@ typedef enum rocsparse_spmm_alg_
     rocsparse_spmm_alg_coo_segmented, /**< SpMM algorithm for COO format using segmented scan. */
     rocsparse_spmm_alg_coo_atomic, /**< SpMM algorithm for COO format using atomics. */
     rocsparse_spmm_alg_csr_row_split, /**< SpMM algorithm for CSR format using row split and shfl. */
-    rocsparse_spmm_alg_csr_merge, /**< SpMM algorithm for CSR format using conversion to COO. */
+    rocsparse_spmm_alg_csr_merge, /**< SpMM algorithm for CSR format using nnz split algorithm. Is the same as rocsparse_spmm_alg_csr_nnz_split. */
     rocsparse_spmm_alg_coo_segmented_atomic, /**< SpMM algorithm for COO format using segmented scan and atomics. */
     rocsparse_spmm_alg_bell, /**< SpMM algorithm for Blocked ELL format. */
-    rocsparse_spmm_alg_bsr /**< SpMM algorithm for BSR format. */
+    rocsparse_spmm_alg_bsr, /**< SpMM algorithm for BSR format. */
+    rocsparse_spmm_alg_csr_merge_path, /**< SpMM algorithm for CSR format using merge path algorithm. */
+    rocsparse_spmm_alg_csr_nnz_split
+    = rocsparse_spmm_alg_csr_merge /**< SpMM algorithm for CSR format using nnz split algorithm. */
 } rocsparse_spmm_alg;
 
 /*! \ingroup types_module
@@ -726,6 +756,7 @@ typedef enum rocsparse_spmm_alg_
 typedef enum rocsparse_sddmm_alg_
 {
     rocsparse_sddmm_alg_default = 0, /**< Default sddmm algorithm for the given format. */
+    rocsparse_sddmm_alg_dense   = 1 /**< Sddmm algorithm using dense blas operations. */
 } rocsparse_sddmm_alg;
 
 /*! \ingroup types_module
